@@ -1,7 +1,7 @@
 package App::wp::xmlrpc;
 
-our $DATE = '2016-11-15'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2017-04-24'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -71,121 +71,187 @@ sub _api {
 
 our %API_Methods = (
     # Posts
-    'wp.getPost' => {args => [
-        ['post_id*', {schema=>'posint*'}],
-        ['fields',   {schema=>'str*'}],
-    ]},
-    'wp.getPosts' => {args => [
-        ['filter',   {schema=>'str*'}],
-    ]},
-    'wp.newPost' => {args => [
-        ['content*', {schema=>'str*'}],
-    ]},
-    'wp.editPost' => {args => [
-        ['content*', {schema=>'str*'}],
-    ]},
-    'wp.deletePost' => {args => [
-        ['post_id*', {schema=>'posint*'}],
-    ]},
-    'wp.getPostType' => {args => [
-        ['post_type_name*', {schema=>'str*'}],
-        ['fields', {schema=>'str*'}],
-    ]},
-    'wp.getPostTypes' => {args => [
-        ['filter', {schema=>'str*'}],
-        ['fields', {schema=>'str*'}],
-    ]},
-    'wp.getPostFormats' => {args => [
-        ['filter', {schema=>'str*'}],
-    ]},
-    'wp.getPostStatusList' => {args => [
-    ]},
+    'wp.getPost' => {
+        args => [
+            ['post_id*', {schema=>'posint*'}],
+            ['fields',   {schema=>'str*'}],
+        ],
+    },
+    'wp.getPosts' => {
+        args => [
+            ['filter',   {schema=>'str*'}],
+        ],
+    },
+    'wp.newPost' => {
+        args => [
+            ['content*', {schema=>'str*'}],
+        ],
+    },
+    'wp.editPost' => {
+        args => [
+            ['content*', {schema=>'str*'}],
+        ],
+    },
+    'wp.deletePost' => {
+        args => [
+            ['post_id*', {schema=>'posint*'}],
+        ],
+    },
+    'wp.getPostType' => {
+        args => [
+            ['post_type_name*', {schema=>'str*'}],
+            ['fields', {schema=>'str*'}],
+        ],
+    },
+    'wp.getPostTypes' => {
+        args => [
+            ['filter', {schema=>'str*'}],
+            ['fields', {schema=>'str*'}],
+        ],
+    },
+    'wp.getPostFormats' => {
+        args => [
+            ['filter', {schema=>'str*'}],
+        ],
+    },
+    'wp.getPostStatusList' => {
+        args => [
+        ],
+    },
 
     # Taxonomies
-    'wp.getTaxonomy' => {args => [
-        ['taxonomy*', {schema=>'str*'}],
-    ]},
-    'wp.getTaxonomies' => {args => [
-    ]},
-    'wp.getTerm' => {args => [
-        ['taxonomy*', {schema=>'str*'}],
-        ['term_id*', {schema=>'posint*'}],
-    ]},
-    'wp.getTerms' => {args => [
-        ['taxonomy*', {schema=>'str*'}],
-    ]},
-    'wp.newTerm' => {args => [
-        ['content*', {schema=>'str*'}],
-    ]},
-    'wp.editTerm' => {args => [
-        ['term_id*', {schema=>'posint*'}],
-        ['content*', {schema=>'str*'}],
-    ]},
-    'wp.deleteTerm' => {args => [
-        ['term_id*', {schema=>'posint*'}],
-    ]},
+    'wp.getTaxonomy' => {
+        args => [
+            ['taxonomy*', {schema=>'str*'}],
+        ],
+    },
+    'wp.getTaxonomies' => {
+        args => [
+        ],
+    },
+    'wp.getTerm' => {
+        args => [
+            ['taxonomy*', {schema=>'str*'}],
+            ['term_id*', {schema=>'posint*'}],
+        ],
+    },
+    'wp.getTerms' => {
+        args => [
+            ['taxonomy*', {schema=>'str*'}],
+        ],
+    },
+    'wp.newTerm' => {
+        args => [
+            ['content*', {schema=>'str*'}],
+        ],
+    },
+    'wp.editTerm' => {
+        args => [
+            ['term_id*', {schema=>'posint*'}],
+            ['content*', {schema=>'str*'}],
+        ],
+    },
+    'wp.deleteTerm' => {
+        args => [
+            ['term_id*', {schema=>'posint*'}],
+        ],
+    },
 
     # Media
-    'wp.getMediaItem' => {args => [
-        ['attachment_id*', {schema=>'posint*'}],
-    ]},
-    'wp.getMediaLibrary' => {args => [
-        ['filter', {schema=>'str*'}],
-    ]},
+    'wp.getMediaItem' => {
+        args => [
+            ['attachment_id*', {schema=>'posint*'}],
+        ],
+    },
+    'wp.getMediaLibrary' => {
+        args => [
+            ['filter', {schema=>'str*'}],
+        ],
+    },
     # TODO: wp.uploadFile
 
     # Comments
-    'wp.getCommentCount' => {args => [
-        ['post_id*', {schema=>'posint*'}],
-    ]},
-    'wp.getComment' => {args => [
-        ['comment_id*', {schema=>'posint*'}],
-    ]},
-    'wp.getComments' => {args => [
-        ['filter', {schema=>'str*'}],
-    ]},
-    'wp.newComment' => {args => [
-        ['post_id*', {schema=>'posint*'}],
-        ['comment*', {schema=>'str*'}],
-    ]},
-    'wp.editComment' => {args => [
-        ['comment_id*', {schema=>'posint*'}],
-        ['comment*', {schema=>'str*'}],
-    ]},
-    'wp.deleteComment' => {args => [
-        ['comment_id*', {schema=>'posint*'}],
-    ]},
-    'wp.getCommentStatusList' => {args => [
-    ]},
+    'wp.getCommentCount' => {
+        args => [
+            ['post_id*', {schema=>'posint*'}],
+        ],
+    },
+    'wp.getComment' => {
+        args => [
+            ['comment_id*', {schema=>'posint*'}],
+        ],
+    },
+    'wp.getComments' => {
+        args => [
+            ['filter', {schema=>'str*'}],
+        ],
+    },
+    'wp.newComment' => {
+        args => [
+            ['post_id*', {schema=>'posint*'}],
+            ['comment*', {schema=>'str*'}],
+        ],
+    },
+    'wp.editComment' => {
+        args => [
+            ['comment_id*', {schema=>'posint*'}],
+            ['comment*', {schema=>'str*'}],
+        ],
+    },
+    'wp.deleteComment' => {
+        args => [
+            ['comment_id*', {schema=>'posint*'}],
+        ],
+    },
+    'wp.getCommentStatusList' => {
+        args => [
+        ],
+    },
 
     # Options
-    'wp.getOptions' => {args => [
-        ['options', {schema=>'str*'}],
-    ]},
-    'wp.setOptions' => {args => [
-        ['options*', {schema=>'str*'}],
-    ]},
+    'wp.getOptions' => {
+        args => [
+            ['options', {schema=>'str*'}],
+        ],
+    },
+    'wp.setOptions' => {
+        args => [
+            ['options*', {schema=>'str*'}],
+        ],
+    },
 
     # Users
-    'wp.getUsersBlogs' => {args => [
-        ['xmlrpc*', {schema=>'str*'}],
-        ['isAdmin*', {schema=>'bool*'}],
-    ]},
-    'wp.getUser' => {args => [
-        ['user_id*', {schema=>'posint*'}],
-        ['fields', {schema=>'str*'}],
-    ]},
-    'wp.getUsers' => {args => [
-        ['fields', {schema=>'str*'}],
-    ]},
-    'wp.getProfile' => {args => [
-        ['fields', {schema=>'str*'}],
-    ]},
-    'wp.editProfile' => {args => [
-        ['content*', {schema=>'str*'}],
-    ]},
-    'wp.getAuthors' => {args => [
-    ]},
+    'wp.getUsersBlogs' => {
+        args => [
+            ['xmlrpc*', {schema=>'str*'}],
+            ['isAdmin*', {schema=>'bool*'}],
+        ],
+    },
+    'wp.getUser' => {
+        args => [
+            ['user_id*', {schema=>'posint*'}],
+            ['fields', {schema=>'str*'}],
+        ],
+    },
+    'wp.getUsers' => {
+        args => [
+            ['fields', {schema=>'str*'}],
+        ],
+    },
+    'wp.getProfile' => {
+        args => [
+            ['fields', {schema=>'str*'}],
+        ],
+    },
+    'wp.editProfile' => {
+        args => [
+            ['content*', {schema=>'str*'}],
+        ],
+    },
+    'wp.getAuthors' => {
+        args => [
+        ],
+    },
 );
 
 GENERATE_API_FUNCTIONS: {
@@ -212,6 +278,7 @@ GENERATE_API_FUNCTIONS: {
                 pos => $pos,
             };
         }
+        $meta->{examples} = $apispec->{examples} if $apispec->{examples};
         *{$funcname} = sub {
             my %args = @_;
             _convert_args_to_struct(\%args);
@@ -236,16 +303,38 @@ App::wp::xmlrpc - A thin layer of CLI over WordPress XML-RPC API
 
 =head1 VERSION
 
-This document describes version 0.002 of App::wp::xmlrpc (from Perl distribution App-wp-xmlrpc), released on 2016-11-15.
+This document describes version 0.003 of App::wp::xmlrpc (from Perl distribution App-wp-xmlrpc), released on 2017-04-24.
 
 =head1 SYNOPSIS
 
-See L<wp-xmlrpc>.
+This module is meant to be used only via the included CLI script L<wp-xmlrpc>.
+If you want to make XML-RPC calls to a WordPress website, you can use
+L<XMLRCCP::Lite> directly, e.g. to delete a comment with ID 13:
+
+ use XMLRPC::Lite;
+ my $call = XMLRPC::Lite->proxy("http://example.org/yourblog")->call(
+     "wp.deleteComment", # method
+     1, # blog ID, usually just set to 1
+     "username",
+     "password",
+     13,
+ );
+ my $fault = $call->fault;
+ if ($fault && $fault->{faultCode}) {
+     die "Can't delete comment: $fault->{faultCode} - $fault->{faultString}";
+ }
+
+To find the list of available methods and arguments, see the WordPress API
+reference (see L</"SEE ALSO">).
 
 =head1 FUNCTIONS
 
 
-=head2 wp_deleteComment(%args) -> [status, msg, result, meta]
+=head2 wp_deleteComment
+
+Usage:
+
+ wp_deleteComment(%args) -> [status, msg, result, meta]
 
 This function is not exported.
 
@@ -277,7 +366,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 wp_deletePost(%args) -> [status, msg, result, meta]
+=head2 wp_deletePost
+
+Usage:
+
+ wp_deletePost(%args) -> [status, msg, result, meta]
 
 This function is not exported.
 
@@ -309,7 +402,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 wp_deleteTerm(%args) -> [status, msg, result, meta]
+=head2 wp_deleteTerm
+
+Usage:
+
+ wp_deleteTerm(%args) -> [status, msg, result, meta]
 
 This function is not exported.
 
@@ -341,7 +438,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 wp_editComment(%args) -> [status, msg, result, meta]
+=head2 wp_editComment
+
+Usage:
+
+ wp_editComment(%args) -> [status, msg, result, meta]
 
 This function is not exported.
 
@@ -375,7 +476,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 wp_editPost(%args) -> [status, msg, result, meta]
+=head2 wp_editPost
+
+Usage:
+
+ wp_editPost(%args) -> [status, msg, result, meta]
 
 This function is not exported.
 
@@ -407,7 +512,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 wp_editProfile(%args) -> [status, msg, result, meta]
+=head2 wp_editProfile
+
+Usage:
+
+ wp_editProfile(%args) -> [status, msg, result, meta]
 
 This function is not exported.
 
@@ -439,7 +548,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 wp_editTerm(%args) -> [status, msg, result, meta]
+=head2 wp_editTerm
+
+Usage:
+
+ wp_editTerm(%args) -> [status, msg, result, meta]
 
 This function is not exported.
 
@@ -473,7 +586,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 wp_getAuthors(%args) -> [status, msg, result, meta]
+=head2 wp_getAuthors
+
+Usage:
+
+ wp_getAuthors(%args) -> [status, msg, result, meta]
 
 This function is not exported.
 
@@ -503,7 +620,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 wp_getComment(%args) -> [status, msg, result, meta]
+=head2 wp_getComment
+
+Usage:
+
+ wp_getComment(%args) -> [status, msg, result, meta]
 
 This function is not exported.
 
@@ -535,7 +656,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 wp_getCommentCount(%args) -> [status, msg, result, meta]
+=head2 wp_getCommentCount
+
+Usage:
+
+ wp_getCommentCount(%args) -> [status, msg, result, meta]
 
 This function is not exported.
 
@@ -567,7 +692,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 wp_getCommentStatusList(%args) -> [status, msg, result, meta]
+=head2 wp_getCommentStatusList
+
+Usage:
+
+ wp_getCommentStatusList(%args) -> [status, msg, result, meta]
 
 This function is not exported.
 
@@ -597,7 +726,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 wp_getComments(%args) -> [status, msg, result, meta]
+=head2 wp_getComments
+
+Usage:
+
+ wp_getComments(%args) -> [status, msg, result, meta]
 
 This function is not exported.
 
@@ -629,7 +762,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 wp_getMediaItem(%args) -> [status, msg, result, meta]
+=head2 wp_getMediaItem
+
+Usage:
+
+ wp_getMediaItem(%args) -> [status, msg, result, meta]
 
 This function is not exported.
 
@@ -661,7 +798,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 wp_getMediaLibrary(%args) -> [status, msg, result, meta]
+=head2 wp_getMediaLibrary
+
+Usage:
+
+ wp_getMediaLibrary(%args) -> [status, msg, result, meta]
 
 This function is not exported.
 
@@ -693,7 +834,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 wp_getOptions(%args) -> [status, msg, result, meta]
+=head2 wp_getOptions
+
+Usage:
+
+ wp_getOptions(%args) -> [status, msg, result, meta]
 
 This function is not exported.
 
@@ -725,7 +870,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 wp_getPost(%args) -> [status, msg, result, meta]
+=head2 wp_getPost
+
+Usage:
+
+ wp_getPost(%args) -> [status, msg, result, meta]
 
 This function is not exported.
 
@@ -759,7 +908,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 wp_getPostFormats(%args) -> [status, msg, result, meta]
+=head2 wp_getPostFormats
+
+Usage:
+
+ wp_getPostFormats(%args) -> [status, msg, result, meta]
 
 This function is not exported.
 
@@ -791,7 +944,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 wp_getPostStatusList(%args) -> [status, msg, result, meta]
+=head2 wp_getPostStatusList
+
+Usage:
+
+ wp_getPostStatusList(%args) -> [status, msg, result, meta]
 
 This function is not exported.
 
@@ -821,7 +978,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 wp_getPostType(%args) -> [status, msg, result, meta]
+=head2 wp_getPostType
+
+Usage:
+
+ wp_getPostType(%args) -> [status, msg, result, meta]
 
 This function is not exported.
 
@@ -855,7 +1016,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 wp_getPostTypes(%args) -> [status, msg, result, meta]
+=head2 wp_getPostTypes
+
+Usage:
+
+ wp_getPostTypes(%args) -> [status, msg, result, meta]
 
 This function is not exported.
 
@@ -889,7 +1054,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 wp_getPosts(%args) -> [status, msg, result, meta]
+=head2 wp_getPosts
+
+Usage:
+
+ wp_getPosts(%args) -> [status, msg, result, meta]
 
 This function is not exported.
 
@@ -921,7 +1090,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 wp_getProfile(%args) -> [status, msg, result, meta]
+=head2 wp_getProfile
+
+Usage:
+
+ wp_getProfile(%args) -> [status, msg, result, meta]
 
 This function is not exported.
 
@@ -953,7 +1126,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 wp_getTaxonomies(%args) -> [status, msg, result, meta]
+=head2 wp_getTaxonomies
+
+Usage:
+
+ wp_getTaxonomies(%args) -> [status, msg, result, meta]
 
 This function is not exported.
 
@@ -983,7 +1160,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 wp_getTaxonomy(%args) -> [status, msg, result, meta]
+=head2 wp_getTaxonomy
+
+Usage:
+
+ wp_getTaxonomy(%args) -> [status, msg, result, meta]
 
 This function is not exported.
 
@@ -1015,7 +1196,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 wp_getTerm(%args) -> [status, msg, result, meta]
+=head2 wp_getTerm
+
+Usage:
+
+ wp_getTerm(%args) -> [status, msg, result, meta]
 
 This function is not exported.
 
@@ -1049,7 +1234,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 wp_getTerms(%args) -> [status, msg, result, meta]
+=head2 wp_getTerms
+
+Usage:
+
+ wp_getTerms(%args) -> [status, msg, result, meta]
 
 This function is not exported.
 
@@ -1081,7 +1270,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 wp_getUser(%args) -> [status, msg, result, meta]
+=head2 wp_getUser
+
+Usage:
+
+ wp_getUser(%args) -> [status, msg, result, meta]
 
 This function is not exported.
 
@@ -1115,7 +1308,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 wp_getUsers(%args) -> [status, msg, result, meta]
+=head2 wp_getUsers
+
+Usage:
+
+ wp_getUsers(%args) -> [status, msg, result, meta]
 
 This function is not exported.
 
@@ -1147,7 +1344,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 wp_getUsersBlogs(%args) -> [status, msg, result, meta]
+=head2 wp_getUsersBlogs
+
+Usage:
+
+ wp_getUsersBlogs(%args) -> [status, msg, result, meta]
 
 This function is not exported.
 
@@ -1181,7 +1382,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 wp_newComment(%args) -> [status, msg, result, meta]
+=head2 wp_newComment
+
+Usage:
+
+ wp_newComment(%args) -> [status, msg, result, meta]
 
 This function is not exported.
 
@@ -1215,7 +1420,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 wp_newPost(%args) -> [status, msg, result, meta]
+=head2 wp_newPost
+
+Usage:
+
+ wp_newPost(%args) -> [status, msg, result, meta]
 
 This function is not exported.
 
@@ -1247,7 +1456,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 wp_newTerm(%args) -> [status, msg, result, meta]
+=head2 wp_newTerm
+
+Usage:
+
+ wp_newTerm(%args) -> [status, msg, result, meta]
 
 This function is not exported.
 
@@ -1279,7 +1492,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 wp_setOptions(%args) -> [status, msg, result, meta]
+=head2 wp_setOptions
+
+Usage:
+
+ wp_setOptions(%args) -> [status, msg, result, meta]
 
 This function is not exported.
 
@@ -1340,13 +1557,15 @@ Other WordPress API CLI on CPAN: L<wordpress-info>, L<wordpress-upload-media>,
 L<wordpress-upload-post> (from L<WordPress::CLI> distribution, also by Leo
 Charre).
 
+L<XMLRPC::Lite>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
